-
-
+
7
+
7
@@ -488,9 +475,9 @@
-
-
-
+
diff --git a/addons/hr/__openerp__.py b/addons/hr/__openerp__.py
index 1135b55034a..71d7d9aa93d 100644
--- a/addons/hr/__openerp__.py
+++ b/addons/hr/__openerp__.py
@@ -43,12 +43,12 @@ You can manage:
'update_xml': [
'security/hr_security.xml',
'security/ir.model.access.csv',
+ 'board_hr_view.xml',
'hr_view.xml',
'hr_department_view.xml',
'process/hr_process.xml',
'hr_installer.xml',
'hr_data.xml',
- 'board_hr_view.xml',
'res_config_view.xml',
],
'demo_xml': [
diff --git a/addons/hr/hr_department_view.xml b/addons/hr/hr_department_view.xml
index 1935cbbd03d..bbf66f0d4c3 100644
--- a/addons/hr/hr_department_view.xml
+++ b/addons/hr/hr_department_view.xml
@@ -13,12 +13,14 @@
form
diff --git a/addons/hr/hr_view.xml b/addons/hr/hr_view.xml
index 5e6953a29d2..750b83d6700 100644
--- a/addons/hr/hr_view.xml
+++ b/addons/hr/hr_view.xml
@@ -9,6 +9,8 @@
+
@@ -18,60 +20,64 @@
@@ -357,16 +363,25 @@
+
+
+
+
+
+
+
+
+
+
+
-
-
-
-
-
-
+
+
+
+
@@ -376,9 +391,6 @@
-
-
-
diff --git a/addons/hr_attendance/hr_attendance_view.xml b/addons/hr_attendance/hr_attendance_view.xml
index e769f3ff684..448e6401cbd 100644
--- a/addons/hr_attendance/hr_attendance_view.xml
+++ b/addons/hr_attendance/hr_attendance_view.xml
@@ -133,12 +133,13 @@
form
-
-
-
-
-
-
+
+
+
+
+
+
+
diff --git a/addons/hr_contract/hr_contract.py b/addons/hr_contract/hr_contract.py
index 4f82d1b3014..1267f13ac04 100644
--- a/addons/hr_contract/hr_contract.py
+++ b/addons/hr_contract/hr_contract.py
@@ -44,7 +44,7 @@ class hr_employee(osv.osv):
'place_of_birth': fields.char('Place of Birth', size=30),
'children': fields.integer('Number of Children'),
'vehicle': fields.char('Company Vehicle', size=64),
- 'vehicle_distance': fields.integer('Home-Work Distance', help="In kilometers"),
+ 'vehicle_distance': fields.integer('Home-Work Dist.', help="In kilometers"),
'contract_ids': fields.one2many('hr.contract', 'employee_id', 'Contracts'),
'contract_id':fields.function(_get_latest_contract, string='Contract', type='many2one', relation="hr.contract", help='Latest contract of the employee'),
}
diff --git a/addons/hr_contract/hr_contract_view.xml b/addons/hr_contract/hr_contract_view.xml
index 11cdba387ca..66f486dc9cc 100644
--- a/addons/hr_contract/hr_contract_view.xml
+++ b/addons/hr_contract/hr_contract_view.xml
@@ -8,30 +8,32 @@
hr.employee
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
-
hr.contract.view.search
hr.contract
@@ -67,34 +69,45 @@
@@ -279,13 +286,17 @@
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
diff --git a/addons/hr_evaluation/report/hr_evaluation_report_view.xml b/addons/hr_evaluation/report/hr_evaluation_report_view.xml
index c9d51139fa7..d855e02eea7 100644
--- a/addons/hr_evaluation/report/hr_evaluation_report_view.xml
+++ b/addons/hr_evaluation/report/hr_evaluation_report_view.xml
@@ -90,7 +90,7 @@
-
+
diff --git a/addons/hr_expense/hr_expense.py b/addons/hr_expense/hr_expense.py
index 9d7ec10cc28..b1192701dfb 100644
--- a/addons/hr_expense/hr_expense.py
+++ b/addons/hr_expense/hr_expense.py
@@ -56,12 +56,12 @@ class hr_expense_expense(osv.osv):
return self.pool.get('res.currency').search(cr, uid, [('rate','=',1.0)], context=context)[0]
_name = "hr.expense.expense"
+ _inherit = ['mail.thread']
_description = "Expense"
_order = "id desc"
_columns = {
'name': fields.char('Description', size=128, required=True),
'id': fields.integer('Sheet ID', readonly=True),
- 'ref': fields.char('Reference', size=32),
'date': fields.date('Date', select=True),
'journal_id': fields.many2one('account.journal', 'Force Journal', help = "The journal used when the expense is invoiced"),
'employee_id': fields.many2one('hr.employee', "Employee", required=True),
diff --git a/addons/hr_expense/hr_expense_view.xml b/addons/hr_expense/hr_expense_view.xml
index dd89a3ab57d..b8868c3319f 100644
--- a/addons/hr_expense/hr_expense_view.xml
+++ b/addons/hr_expense/hr_expense_view.xml
@@ -49,7 +49,6 @@
-
@@ -74,38 +73,44 @@
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -113,17 +118,13 @@
-
-
-
-
-
-
-
+
diff --git a/addons/hr_expense/report/expense.rml b/addons/hr_expense/report/expense.rml
index d0d73aa5ca4..bf456cfc4d6 100644
--- a/addons/hr_expense/report/expense.rml
+++ b/addons/hr_expense/report/expense.rml
@@ -160,7 +160,7 @@
Date
- Reference
+ Description
Validated By
@@ -176,7 +176,7 @@
[[ formatLang(o.date,date=True) ]]
- [[ o.ref ]]
+ [[ o.name ]]
[[ o.user_valid.name ]]
diff --git a/addons/hr_expense/report/hr_expense_report_view.xml b/addons/hr_expense/report/hr_expense_report_view.xml
index 1299f4e9ce5..7877edf4b3a 100644
--- a/addons/hr_expense/report/hr_expense_report_view.xml
+++ b/addons/hr_expense/report/hr_expense_report_view.xml
@@ -8,7 +8,6 @@
tree
-
@@ -105,7 +104,7 @@
-
+
diff --git a/addons/hr_holidays/__openerp__.py b/addons/hr_holidays/__openerp__.py
index c5c2d370cd1..4509508b2be 100644
--- a/addons/hr_holidays/__openerp__.py
+++ b/addons/hr_holidays/__openerp__.py
@@ -58,7 +58,6 @@ Note that:
'hr_holidays_workflow.xml',
'hr_holidays_view.xml',
'hr_holidays_data.xml',
- 'hr_holidays_wizard.xml',
'hr_holidays_report.xml',
'report/hr_holidays_report_view.xml',
'report/available_holidays_view.xml',
diff --git a/addons/hr_holidays/hr_holidays_view.xml b/addons/hr_holidays/hr_holidays_view.xml
index dc541b20ceb..1237cdb14f4 100644
--- a/addons/hr_holidays/hr_holidays_view.xml
+++ b/addons/hr_holidays/hr_holidays_view.xml
@@ -110,35 +110,45 @@
-
-
-
-
-
+
+
+
+
+
+
+
-
-
+
+
+
+
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
-
-
-
-
+
-
-
-
+
@@ -159,31 +169,34 @@
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -342,7 +355,7 @@
form
-
+
@@ -409,8 +422,7 @@
-
-
+
@@ -420,6 +432,7 @@
+
@@ -529,8 +542,13 @@
form
-
-
+
+
+
+
+
+
+
@@ -556,5 +574,14 @@
+
+
diff --git a/addons/hr_holidays/hr_holidays_wizard.xml b/addons/hr_holidays/hr_holidays_wizard.xml
deleted file mode 100644
index efeb8e29115..00000000000
--- a/addons/hr_holidays/hr_holidays_wizard.xml
+++ /dev/null
@@ -1,10 +0,0 @@
-
-
-
-
-
-
diff --git a/addons/hr_holidays/report/available_holidays_view.xml b/addons/hr_holidays/report/available_holidays_view.xml
index 082bf198e34..e7441060204 100644
--- a/addons/hr_holidays/report/available_holidays_view.xml
+++ b/addons/hr_holidays/report/available_holidays_view.xml
@@ -17,7 +17,7 @@
name="Leaves Analysis"
id="menu_hr_available_holidays_report_tree"
action="action_hr_available_holidays_report"
- parent="menu_hr_reporting_holidays"/>
+ parent="hr.menu_hr_reporting" sequence="5" />
diff --git a/addons/hr_holidays/wizard/hr_holidays_summary_department_view.xml b/addons/hr_holidays/wizard/hr_holidays_summary_department_view.xml
index f6f5851c051..c5e408a6748 100644
--- a/addons/hr_holidays/wizard/hr_holidays_summary_department_view.xml
+++ b/addons/hr_holidays/wizard/hr_holidays_summary_department_view.xml
@@ -9,9 +9,8 @@
@@ -33,7 +32,7 @@
diff --git a/addons/hr_payroll/hr_payroll_view.xml b/addons/hr_payroll/hr_payroll_view.xml
index f52c420df8a..bae89ed215b 100644
--- a/addons/hr_payroll/hr_payroll_view.xml
+++ b/addons/hr_payroll/hr_payroll_view.xml
@@ -7,36 +7,6 @@
-
-
- hr.hr.employee.view.form2
- hr.employee
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
hr.contract.view.form.inherit
@@ -45,8 +15,7 @@
-
-
+
@@ -105,7 +74,7 @@
hr.payroll.structure
form
-
+
@@ -249,6 +218,12 @@
+
+
hr.payslip.form
@@ -265,13 +240,18 @@
-
-
-
-
- from
- to
-
+
+
+
+
+
+
+
+
+ From
+ to
+
+
@@ -281,6 +261,7 @@
+
@@ -302,6 +283,7 @@
+
@@ -360,14 +342,18 @@
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
@@ -413,7 +399,27 @@
+
+
+
+ payroll.hr.employee.view.form
+ hr.employee
+
+
+
+
+
+
+
+
+
hr.salary.rule.category.form
@@ -730,12 +736,20 @@
-
+
+
-
-
+
+
+ Period from
+
+ to
+
+
+
+
diff --git a/addons/hr_payroll_account/hr_payroll_account_view.xml b/addons/hr_payroll_account/hr_payroll_account_view.xml
index 8077ed88152..9e3aab3ecb6 100644
--- a/addons/hr_payroll_account/hr_payroll_account_view.xml
+++ b/addons/hr_payroll_account/hr_payroll_account_view.xml
@@ -2,8 +2,6 @@
-
-
hr.payslip.inherit.form
hr.payslip
@@ -27,10 +25,12 @@
-
-
-
-
+
+
+
+
+
+
@@ -44,14 +44,15 @@
form
-
-
-
-
+
+
+
+
+
-
+
@@ -85,12 +86,11 @@
form
-
-
+
-
+
diff --git a/addons/hr_recruitment/hr_recruitment.py b/addons/hr_recruitment/hr_recruitment.py
index 32bebef3dc0..cf04fb918df 100644
--- a/addons/hr_recruitment/hr_recruitment.py
+++ b/addons/hr_recruitment/hr_recruitment.py
@@ -177,7 +177,7 @@ class hr_applicant(base_stage, osv.Model):
return res
_columns = {
- 'name': fields.char('Name', size=128, required=True),
+ 'name': fields.char('Subject', size=128, required=True),
'active': fields.boolean('Active', help="If the active field is set to false, it will allow you to hide the case without removing it."),
'description': fields.text('Description'),
'email_from': fields.char('Email', size=128, help="These people will receive email."),
@@ -209,7 +209,7 @@ class hr_applicant(base_stage, osv.Model):
'salary_expected_extra': fields.char('Expected Salary Extra', size=100, help="Salary Expected by Applicant, extra advantages"),
'salary_proposed': fields.float('Proposed Salary', help="Salary Proposed by the Organisation"),
'salary_expected': fields.float('Expected Salary', help="Salary Expected by Applicant"),
- 'availability': fields.integer('Availability (Days)'),
+ 'availability': fields.integer('Availability'),
'partner_name': fields.char("Applicant's Name", size=64),
'partner_phone': fields.char('Phone', size=32),
'partner_mobile': fields.char('Mobile', size=32),
diff --git a/addons/hr_recruitment/hr_recruitment_view.xml b/addons/hr_recruitment/hr_recruitment_view.xml
index f3585b2e0ac..7e683970fb9 100644
--- a/addons/hr_recruitment/hr_recruitment_view.xml
+++ b/addons/hr_recruitment/hr_recruitment_view.xml
@@ -138,61 +138,61 @@
-
-
+
+
+
-
-
-
-
-
+
+
+
+
+
+
-
-
-
+
+
+
+
+ -
+
+
+
+
+
+
-
-
+
+
+
+
+
+
+
+
+
+
+ ,
+
+
+
+
+ ,
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
@@ -359,15 +359,15 @@
form
-
-
-
-
-
-
+
+
+
+
+
+
diff --git a/addons/hr_recruitment/report/hr_recruitment_report_view.xml b/addons/hr_recruitment/report/hr_recruitment_report_view.xml
index 5ddbe5045ab..9d81d39f240 100644
--- a/addons/hr_recruitment/report/hr_recruitment_report_view.xml
+++ b/addons/hr_recruitment/report/hr_recruitment_report_view.xml
@@ -114,7 +114,7 @@
{'search_default_year':1,'search_default_month':1,'search_default_department':1,'group_by_no_leaf':1,'group_by':[]}
-
+
diff --git a/addons/hr_timesheet/hr_timesheet_report.xml b/addons/hr_timesheet/hr_timesheet_report.xml
index d3d2d745183..487dcd592bd 100644
--- a/addons/hr_timesheet/hr_timesheet_report.xml
+++ b/addons/hr_timesheet/hr_timesheet_report.xml
@@ -1,11 +1,6 @@
-
diff --git a/addons/hr_timesheet/hr_timesheet_view.xml b/addons/hr_timesheet/hr_timesheet_view.xml
index 45bbb6456ef..7875aff12a0 100644
--- a/addons/hr_timesheet/hr_timesheet_view.xml
+++ b/addons/hr_timesheet/hr_timesheet_view.xml
@@ -26,29 +26,38 @@
hr.analytic.timesheet
form
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -112,10 +121,14 @@
hr.employee
-
+
-
-
+
+
+
+
+
+
diff --git a/addons/hr_timesheet/test/hr_timesheet_report.yml b/addons/hr_timesheet/test/hr_timesheet_report.yml
index 097bf764429..ae5b294aa16 100644
--- a/addons/hr_timesheet/test/hr_timesheet_report.yml
+++ b/addons/hr_timesheet/test/hr_timesheet_report.yml
@@ -7,7 +7,7 @@
ctx.update({'model': 'hr.employee','active_ids': []})
data_dict = {'month': time.gmtime()[1], 'year': time.gmtime()[0], 'employee_id' : ref('hr.employee_fp')}
from tools import test_reports
- test_reports.try_report_action(cr, uid, 'action_hr_timesheet_my',wiz_data=data_dict, context=ctx, our_module='hr_timesheet')
+ test_reports.try_report_action(cr, uid, 'action_hr_timesheet_employee',wiz_data=data_dict, context=ctx, our_module='hr_timesheet')
-
Print the HR Timesheet By Employee report through the wizard
@@ -18,4 +18,4 @@
ctx.update({'model': 'hr.employee','active_ids': []})
data_dict = {'month': time.gmtime()[1], 'year': time.gmtime()[0], 'employee_ids' : [(6,0,[ref('hr.employee_fp'),ref('hr.employee_qdp'),ref('hr.employee_al')])]}
from tools import test_reports
- test_reports.try_report_action(cr, uid, 'action_hr_timesheet_users',wiz_data=data_dict, context=ctx, our_module='hr_timesheet')
\ No newline at end of file
+ test_reports.try_report_action(cr, uid, 'action_hr_timesheet_users',wiz_data=data_dict, context=ctx, our_module='hr_timesheet')
diff --git a/addons/hr_timesheet/wizard/hr_timesheet_print_employee_view.xml b/addons/hr_timesheet/wizard/hr_timesheet_print_employee_view.xml
index f72ccd1fc2a..d14646b0249 100644
--- a/addons/hr_timesheet/wizard/hr_timesheet_print_employee_view.xml
+++ b/addons/hr_timesheet/wizard/hr_timesheet_print_employee_view.xml
@@ -34,39 +34,8 @@
-
-
-
- hr.analytical.timesheet.my.form
- hr.analytical.timesheet.employee
- form
-
-
-
-
-
-
-
-
-
-
-
-
-
- My Timesheet
- hr.analytical.timesheet.employee
- form
- tree,form
-
- new
-
-
diff --git a/addons/hr_timesheet/wizard/hr_timesheet_print_users_view.xml b/addons/hr_timesheet/wizard/hr_timesheet_print_users_view.xml
index 32291489627..288a51e34cd 100644
--- a/addons/hr_timesheet/wizard/hr_timesheet_print_users_view.xml
+++ b/addons/hr_timesheet/wizard/hr_timesheet_print_users_view.xml
@@ -10,18 +10,21 @@
-
-
-
-
-
-
+
+
+
+
+
+
+
-
+
+
+
+
@@ -37,9 +40,8 @@
-
+ parent="hr.menu_hr_reporting_timesheet"
+ groups="base.group_hr_manager" sequence="2" icon="STOCK_PRINT"/>
diff --git a/addons/hr_timesheet_invoice/wizard/hr_timesheet_analytic_profit_view.xml b/addons/hr_timesheet_invoice/wizard/hr_timesheet_analytic_profit_view.xml
index c279b27498e..4e4eb7b36d2 100644
--- a/addons/hr_timesheet_invoice/wizard/hr_timesheet_analytic_profit_view.xml
+++ b/addons/hr_timesheet_invoice/wizard/hr_timesheet_analytic_profit_view.xml
@@ -7,23 +7,27 @@
hr.timesheet.analytic.profit
form
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+ -
+
+
+
+
+
+
+
+
+
+
@@ -38,7 +42,7 @@
+ parent="hr.menu_hr_reporting_timesheet" sequence="3" icon="STOCK_PRINT"/>
diff --git a/addons/hr_timesheet_sheet/hr_timesheet_sheet_view.xml b/addons/hr_timesheet_sheet/hr_timesheet_sheet_view.xml
index c43b1206541..6635c38b909 100644
--- a/addons/hr_timesheet_sheet/hr_timesheet_sheet_view.xml
+++ b/addons/hr_timesheet_sheet/hr_timesheet_sheet_view.xml
@@ -62,39 +62,50 @@
-
- From
- to
-
-
-
-
-
-
+ From to
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
-
-
-
-
+
+
+ :
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
@@ -124,8 +135,6 @@
-
-
@@ -136,11 +145,6 @@
-
-
-
-
-
@@ -227,7 +231,7 @@
form
-
+
@@ -349,6 +353,17 @@
+
+
+ hr.timesheet.sheet.employee.extd_form
+ hr.employee
+
+
+
+
+
+
+
diff --git a/addons/hr_timesheet_sheet/report/hr_timesheet_report_view.xml b/addons/hr_timesheet_sheet/report/hr_timesheet_report_view.xml
index 8b102b19f72..fd5d6b0b6d1 100644
--- a/addons/hr_timesheet_sheet/report/hr_timesheet_report_view.xml
+++ b/addons/hr_timesheet_sheet/report/hr_timesheet_report_view.xml
@@ -82,6 +82,6 @@
+ parent="hr.menu_hr_reporting" sequence="3"/>
diff --git a/addons/hr_timesheet_sheet/report/timesheet_report_view.xml b/addons/hr_timesheet_sheet/report/timesheet_report_view.xml
index fe497b6f46c..613f92d3cf6 100644
--- a/addons/hr_timesheet_sheet/report/timesheet_report_view.xml
+++ b/addons/hr_timesheet_sheet/report/timesheet_report_view.xml
@@ -110,6 +110,6 @@
+ parent="hr.menu_hr_reporting" sequence="4" groups="base.group_hr_manager"/>
diff --git a/addons/idea/idea_view.xml b/addons/idea/idea_view.xml
index 31fbb6d3924..9cee10c3cbb 100644
--- a/addons/idea/idea_view.xml
+++ b/addons/idea/idea_view.xml
@@ -78,7 +78,7 @@
diff --git a/addons/l10n_be_hr_payroll/l10n_be_hr_payroll_view.xml b/addons/l10n_be_hr_payroll/l10n_be_hr_payroll_view.xml
index 46caa9f6478..79c7c08ffca 100644
--- a/addons/l10n_be_hr_payroll/l10n_be_hr_payroll_view.xml
+++ b/addons/l10n_be_hr_payroll/l10n_be_hr_payroll_view.xml
@@ -9,23 +9,17 @@
-
+
+
+
-
-
-
-
-
-
-
-
-
+
diff --git a/addons/mail/doc/mail_openchatter_howto.rst b/addons/mail/doc/mail_openchatter_howto.rst
index 7ca52348d99..4c8797e7f8b 100644
--- a/addons/mail/doc/mail_openchatter_howto.rst
+++ b/addons/mail/doc/mail_openchatter_howto.rst
@@ -38,7 +38,7 @@ Make your module inheriting from the ``mail.thread`` class.
# inherit from mail.thread allows the use of OpenChatter
_inherit = ['mail.thread']
-Use the thread viewer widget inside your form view by using the ThreadView widget on the message_ids field inherited from mail.thread.
+Use the thread viewer widget inside your form view by using the mail_thread widget on the message_ids field inherited from mail.thread.
::
@@ -50,7 +50,7 @@ Use the thread viewer widget inside your form view by using the ThreadView widge
[...]
-
+
@@ -131,7 +131,7 @@ The drawback of this method is that it is no longer possible to those subscriber
Messages display management
++++++++++++++++++++++++++++
-By default, the ThreadView widget shows all messages related to the current document beside the document, in the History and comments section. However, you may want to display other messages in the widget. For example, the OpenChatter on res.users model shows
+By default, the mail_thread widget shows all messages related to the current document beside the document, in the History and comments section. However, you may want to display other messages in the widget. For example, the OpenChatter on res.users model shows
- messages related to the user, as usual (messages with ``model = res.users, res_id = current_document_id``)
- messages directly pushed to this user (containing @login)
diff --git a/addons/mail/mail_group_view.xml b/addons/mail/mail_group_view.xml
index 4b9cfd09c3d..6ad1792b3b4 100644
--- a/addons/mail/mail_group_view.xml
+++ b/addons/mail/mail_group_view.xml
@@ -73,7 +73,7 @@
diff --git a/addons/mail/res_partner_view.xml b/addons/mail/res_partner_view.xml
index 0a9860dc979..15f6618c8e5 100644
--- a/addons/mail/res_partner_view.xml
+++ b/addons/mail/res_partner_view.xml
@@ -10,7 +10,7 @@
diff --git a/addons/mail/res_users_view.xml b/addons/mail/res_users_view.xml
index 428f53d092e..918f77e0ace 100644
--- a/addons/mail/res_users_view.xml
+++ b/addons/mail/res_users_view.xml
@@ -28,7 +28,7 @@
-
+
diff --git a/addons/mail/static/src/xml/mail.xml b/addons/mail/static/src/xml/mail.xml
index 2eb3a390933..982fb8aeb2f 100644
--- a/addons/mail/static/src/xml/mail.xml
+++ b/addons/mail/static/src/xml/mail.xml
@@ -56,9 +56,7 @@
-
-
-
+
diff --git a/addons/marketing_campaign/marketing_campaign.py b/addons/marketing_campaign/marketing_campaign.py
index a6294182301..417bd694624 100644
--- a/addons/marketing_campaign/marketing_campaign.py
+++ b/addons/marketing_campaign/marketing_campaign.py
@@ -439,7 +439,7 @@ class marketing_campaign_activity(osv.osv):
'revenue': fields.float('Revenue', help="Set an expected revenue if you consider that every campaign item that has reached this point has generated a certain revenue. You can get revenue statistics in the Reporting section", digits_compute=dp.get_precision('Sale Price')),
'signal': fields.char('Signal', size=128,
help='An activity with a signal can be called programmatically. Be careful, the workitem is always created when a signal is sent'),
- 'keep_if_condition_not_met': fields.boolean("Don't delete workitems",
+ 'keep_if_condition_not_met': fields.boolean("Don't Delete Workitems",
help="By activating this option, workitems that aren't executed because the condition is not met are marked as cancelled instead of being deleted.")
}
diff --git a/addons/marketing_campaign/marketing_campaign_view.xml b/addons/marketing_campaign/marketing_campaign_view.xml
index 41ed78da709..6a06cb33f1d 100644
--- a/addons/marketing_campaign/marketing_campaign_view.xml
+++ b/addons/marketing_campaign/marketing_campaign_view.xml
@@ -9,6 +9,22 @@
Marketing Campaign
======================
-->
+
+
+
+
marketing.campaign.form
@@ -24,20 +40,30 @@
+
+
+
+
+
+
+
+
-
-
+
+
-
+
-
-
-
-
+
+
@@ -143,16 +169,11 @@
-
+
-
-
-
-
-
-
+
@@ -160,7 +181,8 @@
-
+
+
@@ -243,33 +265,34 @@
-
+
-
+
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
-
-
-
+
+
+
+
-
-
+
+
@@ -285,7 +308,8 @@
-
+
+
@@ -363,12 +387,13 @@
-
+
-
+
+
diff --git a/addons/mrp/mrp_view.xml b/addons/mrp/mrp_view.xml
index 9da070bc0f2..6fe3d61a804 100644
--- a/addons/mrp/mrp_view.xml
+++ b/addons/mrp/mrp_view.xml
@@ -796,7 +796,7 @@
@@ -957,9 +957,8 @@
-
-
-
+
+
diff --git a/addons/mrp_operations/mrp_operations_view.xml b/addons/mrp_operations/mrp_operations_view.xml
index a0b318661e6..85cbaca0cbc 100644
--- a/addons/mrp_operations/mrp_operations_view.xml
+++ b/addons/mrp_operations/mrp_operations_view.xml
@@ -112,7 +112,7 @@
diff --git a/addons/procurement/procurement_view.xml b/addons/procurement/procurement_view.xml
index fde8b4ea2fe..3b0404d376b 100644
--- a/addons/procurement/procurement_view.xml
+++ b/addons/procurement/procurement_view.xml
@@ -94,7 +94,7 @@
diff --git a/addons/product/product_view.xml b/addons/product/product_view.xml
index 0fb0b0559f9..cdf4d48c904 100644
--- a/addons/product/product_view.xml
+++ b/addons/product/product_view.xml
@@ -184,7 +184,7 @@
diff --git a/addons/project/i18n/hr.po b/addons/project/i18n/hr.po
index ea508ead52c..83182e409ef 100644
--- a/addons/project/i18n/hr.po
+++ b/addons/project/i18n/hr.po
@@ -7,14 +7,14 @@ msgstr ""
"Project-Id-Version: OpenERP Server 6.0dev\n"
"Report-Msgid-Bugs-To: support@openerp.com\n"
"POT-Creation-Date: 2012-02-08 01:37+0100\n"
-"PO-Revision-Date: 2010-08-03 09:16+0000\n"
-"Last-Translator: Mantavya Gajjar (Open ERP) \n"
+"PO-Revision-Date: 2012-07-05 11:02+0000\n"
+"Last-Translator: Marko Carevic \n"
"Language-Team: Vinteh\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=UTF-8\n"
"Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2012-06-28 04:36+0000\n"
-"X-Generator: Launchpad (build 15505)\n"
+"X-Launchpad-Export-Date: 2012-07-06 04:58+0000\n"
+"X-Generator: Launchpad (build 15558)\n"
"Language: hr\n"
#. module: project
@@ -108,7 +108,7 @@ msgstr "Sati za procjenu"
#. module: project
#: view:project.project:0
msgid "Pending Projects"
-msgstr ""
+msgstr "Projekti na čekanju"
#. module: project
#: help:project.task,remaining_hours:0
@@ -191,7 +191,7 @@ msgstr "Tvrtka"
#. module: project
#: view:report.project.task.user:0
msgid "Pending tasks"
-msgstr ""
+msgstr "Zadaci na čekanju"
#. module: project
#: field:project.task.delegate,prefix:0
@@ -206,7 +206,7 @@ msgstr ""
#. module: project
#: model:process.transition.action,name:project.process_transition_action_openpendingtask0
msgid "Set pending"
-msgstr "Postavite u tijeku"
+msgstr "Staviti na čekanje"
#. module: project
#: selection:project.task,priority:0
@@ -641,7 +641,7 @@ msgstr "Srednji"
#. module: project
#: view:project.task:0 view:project.task.history.cumulative:0
msgid "Pending Tasks"
-msgstr ""
+msgstr "Zadaci na čekanju"
#. module: project
#: view:project.task:0 field:project.task,remaining_hours:0
@@ -705,7 +705,7 @@ msgstr ""
#: selection:project.vs.hours,state:0 view:report.project.task.user:0
#: selection:report.project.task.user,state:0 selection:task.by.days,state:0
msgid "Pending"
-msgstr "U toku"
+msgstr "Na čekanju"
#. module: project
#: field:project.task.delegate,name:0
diff --git a/addons/project/project_view.xml b/addons/project/project_view.xml
index cf501740456..53a56735ec8 100644
--- a/addons/project/project_view.xml
+++ b/addons/project/project_view.xml
@@ -148,7 +148,7 @@
@@ -239,7 +239,7 @@
diff --git a/addons/mail/static/src/js/mail.js b/addons/mail/static/src/js/mail.js
index da54130d093..0f68a548590 100644
--- a/addons/mail/static/src/js/mail.js
+++ b/addons/mail/static/src/js/mail.js
@@ -91,7 +91,7 @@ openerp.mail = function(session) {
this.params = params;
this.params.parent_id = this.params.parent_id || false;
this.params.thread_level = this.params.thread_level || 0;
- this.params.msg_more_limit = this.params.msg_more_limit || 100;
+ this.params.msg_more_limit = this.params.msg_more_limit || 290;
this.params.limit = this.params.limit || 100;
this.params.offset = this.params.offset || 0;
this.params.records = this.params.records || null;
@@ -304,7 +304,6 @@ openerp.mail = function(session) {
// format date according to the user timezone
record.date = session.web.format_value(record.date, {type:"datetime"});
-
var rendered = session.web.qweb.render('mail.Thread.message', {'record': record, 'thread': this, 'params': this.params, 'display': this.display});
$(rendered).appendTo(this.$element.children('div.oe_mail_thread_display:first'));
// expand feature
@@ -497,7 +496,7 @@ openerp.mail = function(session) {
});
session.web.form.widgets.add( 'Thread', 'openerp.mail.Thread');
/** ThreadView widget: thread of comments */
mail.RecordThread = session.web.form.AbstractField.extend({
template: 'mail.RecordThread',
@@ -598,7 +597,7 @@ openerp.mail = function(session) {
return this.session.prefix + '/web/binary/image?session_id=' + this.session.session_id + '&model=' + model + '&field=' + field + '&id=' + (id || '');
},
});
- session.web.form.widgets.add( 'ThreadView', 'openerp.mail.RecordThread');
+ session.web.form.widgets.add( 'mail_thread', 'openerp.mail.RecordThread');
/** WallView widget: a wall of messages */
mail.WallView = session.web.Widget.extend({
@@ -635,6 +634,7 @@ openerp.mail = function(session) {
start: function () {
this._super.apply(this, arguments);
var self = this;
+ this.display_current_user();
// add events
this.add_event_handlers();
// load mail.message search view
@@ -694,6 +694,14 @@ openerp.mail = function(session) {
});
},
+ display_current_user: function () {
+ return this.$element.find('img.oe_mail_msg_image').attr('src', this.thread_get_avatar('res.users', 'avatar', this.session.uid));
+ },
+
+ thread_get_avatar: function(model, field, id) {
+ return this.session.prefix + '/web/binary/image?session_id=' + this.session.session_id + '&model=' + model + '&field=' + field + '&id=' + (id || '');
+ },
+
/**
* Initializes the wall and calls fetch_comments
* @param {Number} limit: number of notifications to fetch
@@ -497,7 +496,7 @@ openerp.mail = function(session) {
});
session.web.form.widgets.add( 'Thread', 'openerp.mail.Thread');
- /** ThreadView widget: thread of comments */
+ /** mail_thread widget: thread of comments */
mail.RecordThread = session.web.form.AbstractField.extend({
template: 'mail.RecordThread',